@@ -1,70 +1,70 @@
-test01 <- function() {
+test01_connect <- function() {
   redisConnect()
 }
 
-test02 <- function() {
+test02_exists <- function() {
   # legacy exists test
   redisFlushAll()
   checkEquals(FALSE, redisExists('foo'))
 }
 
-test03 <- function() {
+test03_delete <- function() {
   # delete test
   redisFlushAll()
   checkEquals(FALSE, suppressWarnings(redisDelete('foo')))
 }
 
-test04 <- function() {
+test04_empty_get <- function() {
   # empty get test
   redisFlushAll()
   checkTrue(is.null(redisGet('foo')))
 }
 
-test05 <- function() {
+test05_set <- function() {
   # simple set test
   checkEquals(TRUE, redisSet('foo', 'bar'))
 }
 
-test06 <- function() {
+test06_getset <- function() {
   # simple getset test
   checkEquals('bar', redisGetSet('foo', 'zip'))
 }
 
-test07 <- function() {
+test07_get <- function() {
   # getset confirm
   checkEquals('zip', redisGet('foo'))
 }
 
-test08 <- function() {
+test08_serialization <- function() {
   # set/serialize test
   foo <- runif(10)
   redisSet('foo', foo)
   checkEqualsNumeric(foo, redisGet('foo'))
 }
 
-test09 <- function() {
+test09_type <- function() {
   # simple type check
   checkEquals('string', redisType('foo'))
 }
 
-test10 <- function() {
+test10_mget <- function() {
   # mget test
   redisSet('foo', 'bar')
   redisSet('bar', 'foo')
   checkEquals(list(foo='bar', bar='foo'), redisMGet(c('foo', 'bar')))
 }
 
-test11 <- function() {
+test11_mset_simple <- function() {
   # simple mset test
   checkEquals(TRUE, redisMSet(list(foo='foo',bar='bar')))
 }
 
-test12 <- function() {
+test12_get <- function() {
   # simple mset confirm
   checkEquals('foo', redisGet('foo'))
 }
 
-test13 <- function() {
+test13_mset <- function() {
   # real mset test
   redisDelete(c('foo', 'bar'))
   redisMSet(list(foo='bar',bar='foo'))
@@ -72,7 +72,7 @@ test13 <- function() {
   redisDelete(c('foo', 'bar'))
 }
 
-test14 <- function() {
+test14_exists <- function() {
   # real exists test
   checkEquals(FALSE, redisExists('foo'))
   redisSet('foo', 1)
@@ -97,7 +97,7 @@ test14 <- function() {
 ###  redisDelete('foo')
 ###}
 
-test17 <- function() {
+test17_expire <- function() {
   # expire test
   redisSet('foo', 1)
   redisExpire('foo', 1)
@@ -107,7 +107,7 @@ test17 <- function() {
   # to get unix time in R. -PS
 }
 
-test18 <- function() {
+test18_rename <- function() {
   # rename/renamenx test
   redisSet('foo', 1)
   redisSet('bar', 2)
@@ -120,7 +120,7 @@ test18 <- function() {
   checkEquals(2, redisGet('bar'))
 }
 
-test19 <- function() {
+test19_setmsetnx <- function() {
   # set/mset nx mode test
   redisFlushAll()
   checkTrue(redisSet('foo', 1, NX=TRUE))
@@ -129,12 +129,5 @@ test19 <- function() {
   redisDelete('foo')
   checkTrue(redisMSet(list(foo=1,bar=2), NX=TRUE))
   redisDelete(c('foo','bar'))
-}  
-
-test98 <- function() {
-  suppressWarnings(redisDelete(c('foo','bar')))
 }
 
-test99 <- function() {
-  redisClose()
-}
